image

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Image

type Image struct {
	base.OutputCommand
	base.InputCommand
	// Image is the image to superimpose as an overlay to the image.
	Image flags.Filename `short:"y" long:"image" description:"The image to superimpose as an overlay to the given image" optional:"true"`
	// Point is the position in the image where the image will be superimposed.
	Point base.Point `short:"p" long:"point" description:"The coordinates where the image will be superimposed, as an (x,y) point" optional:"true"`
}

Image is the command that superimposes an image as an overlay to the given image.

func (*Image) Execute

func (cmd *Image) Execute(args []string) error

Execute is the real implementation of the Image command.

Jump to