Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Text ¶
type Text struct {
base.InputCommand
base.OutputCommand
// Text is the text to write as an overlay to the image.
Text string `short:"t" long:"text" description:"The text to add as an overlay to the given image" optional:"true"`
// Point is the position in the image where the text will start.
Point base.Point `short:"p" long:"point" description:"The coordinates where the text will be written, as an (x,y) point" optional:"true"`
// Font is the font to use for writing to the image.
Font flags.Filename `short:"f" long:"font" description:"The name of the font to be used for writing" optional:"true"`
// Colour is the colour of the font to be used for writing to the image.
Colour base.Colour `short:"c" long:"colour" description:"The colour of the font to be used for writing" optional:"true" default:"#000000"`
// Size is the size of font to use for writing to the image.
Size float64 `short:"s" long:"size" description:"The size of the font to be used for writing" optional:"true" default:"12"`
}
Text is the command that adds text as an overlay to an image.
Click to show internal directories.
Click to hide internal directories.